embassy-stm32

Crates

git

Versions

stm32wb55vy

Flavors

CoreId

Enum CoreId 

#[repr(u8)]
pub enum CoreId { Core0 = 4, Core1 = 8, }
The enum values are identical to the bus master IDs / core Ids defined for each chip family (i.e. stm32h747 see rm0399 table 95)

Variants



Core0 = 4

Cortex-M4, core 1



Core1 = 8

Cortex-M0+, core 2.

Implementations

Source

impl CoreId

pub fn current() -> Self

Get the current core id This code assume that it is only executed on a Cortex-M M0+, M4 or M7 core.

pub const fn other(&self) -> Self

Get the other core id

pub const fn to_index(&self) -> u8

Translates the core ID to an index into the interrupt registers.